@@ -33,6 +33,7 @@ namespace ucommon {
 #else
 const strsize_t String::npos = (strsize_t)(-1);
 const size_t memstring::header = sizeof(cstring);
+const char String::eos = '\0';
 #endif
 
 String::cstring::cstring(strsize_t size) :
@@ -2000,6 +2001,18 @@ unsigned String::hexsize(const char *format)
     return count;
 }
 
+String String::hex(const unsigned char *binary, size_t size)
+{
+    strsize_t ssize = (strsize_t)(size * 2);
+    String out(ssize, ' ');
+    char *buf = out.c_mem();
+    while(size--) {
+        snprintf(buf, 3, "%02x", *(binary++));
+        buf += 2;
+    }
+    return out;
+} 
+
 unsigned String::hexdump(const unsigned char *binary, char *string, const char *format)
 {
     unsigned count = 0;
@@ -2025,7 +2038,7 @@ unsigned String::hexdump(const unsigned char *binary, char *string, const char *
     return count;
 }
 
-static unsigned hex(char ch)
+static unsigned hexcode(char ch)
 {
     if(ch >= '0' && ch <= '9')
         return ch - '0';
@@ -2050,7 +2063,7 @@ unsigned String::hexpack(unsigned char *binary, const char *string, const char *
             format = ep;
             count += skip * 2;
             while(skip--) {
-                *(binary++) = hex(string[0]) * 16 + hex(string[1]);
+                *(binary++) = hexcode(string[0]) * 16 + hexcode(string[1]);
                 string += 2;
             }
         }
@@ -2206,6 +2219,15 @@ String str(CharacterProtocol *p, strsize_t size)
 static const unsigned char alphabet[65] =
     "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
+String String::b64(const uint8_t *bin, size_t size)
+{
+    strsize_t dsize = (strsize_t)((size * 4 / 3) + 1);
+    String out(dsize, String::eos);
+
+    b64encode(out.c_mem(), bin, size);
+    return out;
+}
+
 size_t String::b64encode(char *dest, const uint8_t *bin, size_t size, size_t dsize)
 {
     assert(dest != NULL && bin != NULL);
