@@ -296,26 +296,39 @@ public:
         // generated keysize
         size_t keysize, blksize;
 
-        Key(const char *cipher);
-        Key();
+        Key(const char *ciper);
 
         void set(const char *cipher);
 
-        void set(const char *cipher, const char *digest);
-
-        void assign(const char *key, size_t size, const unsigned char *salt, unsigned rounds);
-
     public:
+        Key();
+
         Key(const char *cipher, const char *digest, const char *text, size_t size = 0, const unsigned char *salt = NULL, unsigned rounds = 1);
 
+        Key(const char *cipher, const uint8_t *iv, size_t ivsize);
+
         Key(const char *cipher, const char *digest);
 
         ~Key();
 
+        void set(const unsigned char *key, size_t size);
+
+        void set(const char *cipher, const char *digest);
+
+        void set(const char *cipher, const uint8_t *iv, size_t ivsize);
+
+        void assign(const char *key, size_t size, const unsigned char *salt, unsigned rounds);
+
         void assign(const char *key, size_t size = 0);
 
         void clear(void);
 
+        String b64(void);
+
+        void b64(const char *string);
+
+        size_t get(uint8_t *key, uint8_t *ivout = NULL);
+
         inline size_t size(void) const
             {return keysize;}
 
@@ -525,6 +538,17 @@ public:
     static void uuid(char *string, const char *name, const unsigned char *ns = NULL);
 
     static String uuid(const char *name, const unsigned char *ns = NULL);
+
+    /**
+     * Shortcut for short md5 digests if supported...
+     * @param text to create a digest for.
+     * @return digest string.
+     */
+    static String md5(const char *text);
+
+    static String sha1(const char *text);
+
+    static String sha256(const char *text);
 };
 
 /**
