@@ -282,13 +282,12 @@ protected:
     strsize_t getStringSize(void) const;
 
 public:
-    /**
-     * A constant for an invalid position value.
-     */
 #if _MSC_VER > 1400        // windows broken dll linkage issue...
     const static strsize_t npos = ((strsize_t)-1);
+    const static char eos = '\0';
 #else
     static const strsize_t npos;
+    static const char eos;
 #endif
 
 
@@ -1350,6 +1349,14 @@ public:
     inline static long tol(const char *text, char **pointer = NULL)
         {return strtol(text, pointer, 0);}
 
+    /**
+     * Standard radix 64 string encoding.
+     * @param binary data to encode.
+     * @param size of binary data to encode.
+     * @return encoded string.
+     */
+    static String b64(const uint8_t *binary, size_t size);
+
     /**
      * Standard radix 64 encoding.
      * @param string of encoded text save into.
@@ -1385,6 +1392,14 @@ public:
      */
     static uint16_t crc16(uint8_t *binary, size_t size);
 
+    /**
+     * Convert binary data buffer into hex string.
+     * @param binary data to convert.
+     * @param size of data.
+     * @return string from data.
+     */
+    static String hex(const unsigned char *binary, size_t size);
+
     /**
      * Dump hex data to a string buffer.
      * @param binary memory to dump.
